@@ -100,7 +100,7 @@ class ZeebeWorker:
                         'Zeebe cannot handle this amount of requests, retrying with a backoff\n'
                         + repr(e))
                     time.sleep(backoff_interval / 1000)
-                elif e.code() == grpc.SatusCode.INTERNAL:
+                elif e.code() == grpc.StatusCode.INTERNAL:
                     logging.error('Zeebe had an internal error between the gateway and the broker \
                                    Retrying with a backoff\n' + repr(e))
                     time.sleep(backoff_interval / 1000)
